"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AreasSocialesService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const areas_sociales_entity_1 = require("./areas-sociales.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let AreasSocialesService = class AreasSocialesService {
    constructor(areasSocialesRepository) {
        this.areasSocialesRepository = areasSocialesRepository;
    }
    async getDataSinInmueble(inmueble_id) {
        const areasSociales = await this.areasSocialesRepository
            .createQueryBuilder('ars')
            .where('ars.id NOT IN (SELECT ims.areas_sociales_id FROM inmueble_areas_sociales ims WHERE ims.inmueble_id = :inmueble_id)', { inmueble_id })
            .andWhere('ars.deleted_at IS NULL')
            .getMany();
        if (!areasSociales.length) {
            throw new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        return areasSociales.map(area => ({
            ...area,
            created_at: (0, date_fns_1.format)(new Date(area.created_at), 'dd/MM/yyyy'),
            updated_at: (0, date_fns_1.format)(new Date(area.updated_at), 'dd/MM/yyyy'),
        }));
    }
    async getDataAll() {
        const areasSociales = await this.areasSocialesRepository.createQueryBuilder('areas_sociales')
            .andWhere('areas_sociales.deleted_at IS NULL')
            .getMany();
        if (!areasSociales.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return areasSociales.map(areasSociales => ({
                ...areasSociales,
                created_at: (0, date_fns_1.format)(areasSociales.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(areasSociales.updated_at, 'dd/MM/yyyy'),
            }));
        }
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const [data, total] = await this.areasSocialesRepository.createQueryBuilder('areas_sociales')
            .andWhere('areas_sociales.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(areasSociales => ({
                ...areasSociales,
                created_at: (0, date_fns_1.format)(areasSociales.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(areasSociales.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async getDataById(id) {
        const areasSociales = await this.areasSocialesRepository.createQueryBuilder('areas_sociales')
            .andWhere('areas_sociales.deleted_at IS NULL')
            .where('areas_sociales.id = :id', { id })
            .getOne();
        if (!areasSociales) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...areasSociales,
                created_at: (0, date_fns_1.format)(areasSociales.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(areasSociales.updated_at, 'dd/MM/yyyy'),
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = this.areasSocialesRepository.createQueryBuilder('areas_sociales')
            .andWhere('areas_sociales.deleted_at IS NULL');
        if (params.nombre) {
            console.log('params:');
            console.log(params);
            query.andWhere('areas_sociales.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        console.log('data:');
        console.log(data);
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(areasSociales => ({
                ...areasSociales,
                created_at: (0, date_fns_1.format)(areasSociales.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(areasSociales.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async createData(areasSociales) {
        const areasSocialesFound = await this.areasSocialesRepository.findOne({
            where: {
                nombre: areasSociales.nombre,
                deleted_at: null
            }
        });
        if (areasSocialesFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Area Social ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            const newAreasSociales = this.areasSocialesRepository.create(areasSociales);
            const savedAreaSocial = await this.areasSocialesRepository.save(newAreasSociales);
            const formattedData = {
                ...savedAreaSocial,
                created_at: (0, date_fns_1.format)(savedAreaSocial.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedAreaSocial.updated_at, 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Area social creada exitosamente',
            };
        }
    }
    async updateData(id, areasSociales) {
        const areasSocialesFound = await this.areasSocialesRepository.findOne({
            where: {
                id: id
            }
        });
        if (!areasSocialesFound) {
            return new common_1.HttpException('Areas Sociales no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const { created_at } = areasSocialesFound;
            const updateAreasSociales = Object.assign(areasSocialesFound, areasSociales);
            updateAreasSociales.updated_at = new Date();
            updateAreasSociales.created_at = created_at;
            const data = await this.areasSocialesRepository.save(updateAreasSociales);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(new Date(data.created_at), 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(new Date(data.updated_at), 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Area social actualizada exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.areasSocialesRepository.createQueryBuilder()
            .update(areas_sociales_entity_1.AreasSociales)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Areas Sociales no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.AreasSocialesService = AreasSocialesService;
exports.AreasSocialesService = AreasSocialesService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(areas_sociales_entity_1.AreasSociales)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], AreasSocialesService);
//# sourceMappingURL=areas-sociales.service.js.map