"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BusquedasService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const busquedas_entity_1 = require("./busquedas.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let BusquedasService = class BusquedasService {
    constructor(busquedaRepository) {
        this.busquedaRepository = busquedaRepository;
    }
    async createData(busqueda) {
        const busquedaFound = await this.busquedaRepository.findOne({
            where: {
                filtros: busqueda.filtros
            }
        });
        if (busquedaFound) {
            return new common_1.HttpException('Busqueda ya existe', common_1.HttpStatus.CONFLICT);
        }
        else {
            const newBusqueda = this.busquedaRepository.create(busqueda);
            return this.busquedaRepository.save(newBusqueda);
        }
    }
    async getData() {
        const data = await this.busquedaRepository.createQueryBuilder('busquedas')
            .leftJoinAndSelect('busquedas.user', 'user')
            .where('busquedas.deleted_at IS NULL')
            .getMany();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return data.map(busquedas => ({
                ...busquedas,
                created_at: (0, date_fns_1.format)(busquedas.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(busquedas.updated_at, 'dd/MM/yyyy'),
                user: {
                    ...busquedas.user,
                    created_at: (0, date_fns_1.format)(new Date(busquedas.user.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(busquedas.user.updated_at), 'dd/MM/yyyy'),
                }
            }));
        }
    }
    async getDataById(id) {
        const busquedas = await this.busquedaRepository.createQueryBuilder('busquedas')
            .leftJoinAndSelect('busquedas.user', 'user')
            .where('busquedas.deleted_at IS NULL')
            .where('busquedas.id = :id', { id })
            .getOne();
        if (!busquedas) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...busquedas,
                created_at: (0, date_fns_1.format)(busquedas.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(busquedas.updated_at, 'dd/MM/yyyy'),
                user: {
                    ...busquedas.user,
                    created_at: (0, date_fns_1.format)(new Date(busquedas.user.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(busquedas.user.updated_at), 'dd/MM/yyyy'),
                }
            };
        }
    }
    async createTipoVivienda(busqueda) {
        const busquedaFound = await this.busquedaRepository.findOne({
            where: {
                filtros: busqueda.filtros,
                deleted_at: null
            }
        });
        if (busquedaFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Busqueda ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            const newBusqueda = this.busquedaRepository.create(busqueda);
            const savedBusqueda = await this.busquedaRepository.save(newBusqueda);
            const formattedData = {
                ...savedBusqueda,
                created_at: (0, date_fns_1.format)(savedBusqueda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedBusqueda.updated_at, 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Busqueda creada exitosamente',
            };
        }
    }
    async updateData(id, busqueda) {
        const busquedaFound = await this.busquedaRepository.findOne({
            where: {
                id: id
            }
        });
        if (!busquedaFound) {
            return new common_1.HttpException('Favorito no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const updateBusqueda = Object.assign(busquedaFound, busqueda);
            updateBusqueda.updated_at = new Date();
            return this.busquedaRepository.save(updateBusqueda);
        }
    }
    async deleteData(id) {
        const rs = await this.busquedaRepository.createQueryBuilder()
            .update(busquedas_entity_1.Busquedas)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Busquedas no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.BusquedasService = BusquedasService;
exports.BusquedasService = BusquedasService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(busquedas_entity_1.Busquedas)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], BusquedasService);
//# sourceMappingURL=busquedas.service.js.map