"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DepartamentoService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const departamento_entity_1 = require("./departamento.entity");
const pais_entity_1 = require("../pais/pais.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let DepartamentoService = class DepartamentoService {
    constructor(departamentoRepository, paisRepository) {
        this.departamentoRepository = departamentoRepository;
        this.paisRepository = paisRepository;
    }
    async getDataAll() {
        const departamento = await this.departamentoRepository.createQueryBuilder('departamento')
            .leftJoinAndSelect('departamento.provincia', 'provincia')
            .andWhere('departamento.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL')
            .getMany();
        if (!departamento.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return departamento.map(departamento => ({
                ...departamento,
                created_at: (0, date_fns_1.format)(departamento.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(departamento.updated_at, 'dd/MM/yyyy'),
                provincia: departamento.provincia.map(us => ({
                    ...us,
                    created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                })),
            }));
        }
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const [data, total] = await this.departamentoRepository.createQueryBuilder('departamento')
            .leftJoinAndSelect('departamento.provincia', 'provincia')
            .leftJoinAndSelect('departamento.pais', 'pais')
            .andWhere('departamento.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL')
            .andWhere('pais.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(departamento => ({
                ...departamento,
                created_at: (0, date_fns_1.format)(departamento.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(departamento.updated_at, 'dd/MM/yyyy'),
                provincia: departamento.provincia.map(us => ({
                    ...us,
                    created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                })),
                pais: {
                    ...departamento.pais,
                    created_at: (0, date_fns_1.format)(new Date(departamento.pais.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(departamento.pais.updated_at), 'dd/MM/yyyy'),
                },
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = this.departamentoRepository.createQueryBuilder('departamento')
            .leftJoinAndSelect('departamento.provincia', 'provincia')
            .leftJoinAndSelect('departamento.pais', 'pais')
            .andWhere('departamento.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL')
            .andWhere('pais.deleted_at IS NULL');
        if (params.nombre) {
            console.log('params:');
            console.log(params);
            query.andWhere('departamento.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        if (params.pais_id) {
            query.andWhere('departamento.pais_id = :pais_id', { pais_id: `${params.pais_id}` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        console.log('data:');
        console.log(data);
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(departamento => ({
                ...departamento,
                created_at: (0, date_fns_1.format)(departamento.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(departamento.updated_at, 'dd/MM/yyyy'),
                provincia: departamento.provincia.map(us => ({
                    ...us,
                    created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                })),
                pais: {
                    ...departamento.pais,
                    created_at: (0, date_fns_1.format)(new Date(departamento.pais.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(departamento.pais.updated_at), 'dd/MM/yyyy'),
                },
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async getDataById(id) {
        const departamento = await this.departamentoRepository.createQueryBuilder('departamento')
            .leftJoinAndSelect('departamento.provincia', 'provincia')
            .andWhere('departamento.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL')
            .where('departamento.id = :id', { id })
            .getOne();
        if (!departamento) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...departamento,
                created_at: (0, date_fns_1.format)(departamento.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(departamento.updated_at, 'dd/MM/yyyy'),
                provincia: departamento.provincia.map(us => ({
                    ...us,
                    created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                })),
            };
        }
    }
    async createData(departamento) {
        const departamentoFound = await this.departamentoRepository.findOne({
            where: {
                nombre: departamento.nombre,
                deleted_at: null
            },
            relations: ['pais']
        });
        if (departamentoFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Departamento ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            let pais = null;
            if (departamento.pais_id) {
                pais = await this.paisRepository.findOne({
                    where: { id: departamento.pais_id },
                });
                if (!pais) {
                    return new common_1.HttpException('Pais no encontrado', common_1.HttpStatus.NOT_FOUND);
                }
            }
            const newDepartamento = this.departamentoRepository.create({
                ...departamento,
                pais,
            });
            const savedDepartamento = await this.departamentoRepository.save(newDepartamento);
            const formattedData = {
                ...savedDepartamento,
                created_at: (0, date_fns_1.format)(savedDepartamento.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedDepartamento.updated_at, 'dd/MM/yyyy'),
                provincia: savedDepartamento.provincia
                    ? savedDepartamento.provincia.map((us) => ({
                        ...us,
                        created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                    }))
                    : [],
                pais: savedDepartamento.pais
                    ? {
                        ...savedDepartamento.pais,
                        created_at: (0, date_fns_1.format)(new Date(savedDepartamento.pais.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(savedDepartamento.pais.updated_at), 'dd/MM/yyyy'),
                    }
                    : null,
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Departamento creado exitosamente',
            };
        }
    }
    async updateData(id, departamento) {
        const departamentoFound = await this.departamentoRepository.findOne({
            where: {
                id: id
            }
        });
        if (!departamentoFound) {
            return new common_1.HttpException('Departamento no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const { created_at } = departamentoFound;
            const updateDepartamento = Object.assign(departamentoFound, departamento);
            updateDepartamento.updated_at = new Date();
            updateDepartamento.created_at = created_at;
            const data = await this.departamentoRepository.save(updateDepartamento);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(new Date(data.created_at), 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(new Date(data.updated_at), 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Departamento actualizado exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.departamentoRepository.createQueryBuilder()
            .update(departamento_entity_1.Departamento)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Departamento no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.DepartamentoService = DepartamentoService;
exports.DepartamentoService = DepartamentoService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(departamento_entity_1.Departamento)),
    __param(1, (0, typeorm_1.InjectRepository)(pais_entity_1.Pais)),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        typeorm_2.Repository])
], DepartamentoService);
//# sourceMappingURL=departamento.service.js.map