"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DistritoService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const distrito_entity_1 = require("./distrito.entity");
const provincia_entity_1 = require("../provincia/provincia.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let DistritoService = class DistritoService {
    constructor(distritoRepository, provinciaRepository) {
        this.distritoRepository = distritoRepository;
        this.provinciaRepository = provinciaRepository;
    }
    async getDataAll() {
        const distrito = await this.distritoRepository.createQueryBuilder('distrito')
            .andWhere('distrito.deleted_at IS NULL')
            .getMany();
        if (!distrito.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return distrito.map(distrito => ({
                ...distrito,
                created_at: (0, date_fns_1.format)(distrito.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(distrito.updated_at, 'dd/MM/yyyy'),
            }));
        }
    }
    async getAutocompleteData(query) {
        if (!query || query.trim() === '') {
            return {
                data: [],
                statusCode: common_1.HttpStatus.NOT_FOUND,
                message: 'No existen parametro de busqueda',
            };
        }
        else {
            const distritos = await this.distritoRepository
                .createQueryBuilder('distrito')
                .leftJoinAndSelect('distrito.provincia', 'provincia')
                .leftJoinAndSelect('provincia.departamento', 'departamento')
                .leftJoinAndSelect('departamento.pais', 'pais')
                .andWhere('distrito.deleted_at IS NULL')
                .andWhere('provincia.deleted_at IS NULL')
                .andWhere('departamento.deleted_at IS NULL')
                .andWhere('pais.deleted_at IS NULL')
                .andWhere('distrito.nombre LIKE :query', { query: `%${query}%` })
                .getMany();
            if (!distritos.length) {
                const distritosV = [];
                distritosV.push({ nombre: 'no existen registros'
                });
                return {
                    data: distritosV,
                    statusCode: common_1.HttpStatus.NOT_FOUND,
                    message: 'No existen registros',
                };
            }
            else {
                const formattedData = distritos.map((distrito) => ({
                    id: distrito.id,
                    nombre: distrito.nombre,
                    created_at: (0, date_fns_1.format)(distrito.created_at, 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(distrito.updated_at, 'dd/MM/yyyy'),
                    provincia: {
                        ...distrito.provincia,
                        created_at: (0, date_fns_1.format)(new Date(distrito.provincia.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(distrito.provincia.updated_at), 'dd/MM/yyyy'),
                        departamento: {
                            ...distrito.provincia.departamento,
                            created_at: (0, date_fns_1.format)(new Date(distrito.provincia.departamento.created_at), 'dd/MM/yyyy'),
                            updated_at: (0, date_fns_1.format)(new Date(distrito.provincia.departamento.updated_at), 'dd/MM/yyyy'),
                            pais: {
                                ...distrito.provincia.departamento.pais,
                                created_at: (0, date_fns_1.format)(new Date(distrito.provincia.departamento.pais.created_at), 'dd/MM/yyyy'),
                                updated_at: (0, date_fns_1.format)(new Date(distrito.provincia.departamento.pais.updated_at), 'dd/MM/yyyy'),
                            },
                        },
                    },
                }));
                return {
                    data: formattedData,
                    statusCode: common_1.HttpStatus.OK,
                    message: 'Datos obtenidos correctamente',
                };
            }
        }
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const [data, total] = await this.distritoRepository.createQueryBuilder('distrito')
            .leftJoinAndSelect('distrito.provincia', 'provincia')
            .andWhere('distrito.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(distrito => ({
                ...distrito,
                created_at: (0, date_fns_1.format)(distrito.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(distrito.updated_at, 'dd/MM/yyyy'),
                provincia: {
                    ...distrito.provincia,
                    created_at: (0, date_fns_1.format)(new Date(distrito.provincia.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(distrito.provincia.updated_at), 'dd/MM/yyyy'),
                },
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = await this.distritoRepository.createQueryBuilder('distrito')
            .leftJoinAndSelect('distrito.provincia', 'provincia')
            .andWhere('distrito.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL');
        if (params.nombre) {
            query.andWhere('distrito.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        if (params.provincia_id) {
            query.andWhere('distrito.provincia_id = :provincia_id', { provincia_id: `${params.provincia_id}` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        console.log('data:');
        console.log(data);
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(distrito => ({
                ...distrito,
                created_at: (0, date_fns_1.format)(distrito.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(distrito.updated_at, 'dd/MM/yyyy'),
                provincia: {
                    ...distrito.provincia,
                    created_at: (0, date_fns_1.format)(new Date(distrito.provincia.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(distrito.provincia.updated_at), 'dd/MM/yyyy'),
                },
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async getDataById(id) {
        const distrito = await this.distritoRepository.createQueryBuilder('distrito')
            .andWhere('distrito.deleted_at IS NULL')
            .where('distrito.id = :id', { id })
            .getOne();
        if (!distrito) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...distrito,
                created_at: (0, date_fns_1.format)(distrito.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(distrito.updated_at, 'dd/MM/yyyy'),
            };
        }
    }
    async getDataByProvinciaId(provincia_id) {
        const distrito = await this.distritoRepository.createQueryBuilder('distrito')
            .andWhere('distrito.deleted_at IS NULL')
            .where('distrito.provincia_id = :provincia_id', { provincia_id })
            .getMany();
        if (!distrito.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return distrito.map(distrito => ({
                ...distrito,
                created_at: (0, date_fns_1.format)(distrito.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(distrito.updated_at, 'dd/MM/yyyy'),
            }));
        }
    }
    async createData(distrito) {
        const distritoFound = await this.distritoRepository.findOne({
            where: {
                nombre: distrito.nombre,
                deleted_at: null
            },
            relations: ['provincia']
        });
        if (distritoFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'distrito ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            let provincia = null;
            if (distrito.provincia_id) {
                provincia = await this.provinciaRepository.findOne({
                    where: { id: distrito.provincia_id },
                });
                if (!provincia) {
                    return new common_1.HttpException('Provincia no encontrado', common_1.HttpStatus.NOT_FOUND);
                }
            }
            const newDistrito = this.distritoRepository.create({
                ...distrito,
                provincia,
            });
            const savedDistrito = await this.provinciaRepository.save(newDistrito);
            const formattedData = {
                ...savedDistrito,
                created_at: (0, date_fns_1.format)(savedDistrito.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedDistrito.updated_at, 'dd/MM/yyyy'),
                provincia: savedDistrito.provincia
                    ? {
                        ...savedDistrito.provincia,
                        created_at: (0, date_fns_1.format)(new Date(savedDistrito.provincia.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(savedDistrito.provincia.updated_at), 'dd/MM/yyyy'),
                    }
                    : null,
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Distrito creado exitosamente',
            };
        }
    }
    async updateData(id, distrito) {
        const distritoFound = await this.distritoRepository.findOne({
            where: {
                id: id
            }
        });
        if (!distritoFound) {
            return new common_1.HttpException('distrito no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const { created_at } = distritoFound;
            const updateDistrito = Object.assign(distritoFound, distrito);
            updateDistrito.updated_at = new Date();
            updateDistrito.created_at = created_at;
            const data = await this.distritoRepository.save(updateDistrito);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(new Date(data.created_at), 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(new Date(data.updated_at), 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Departamento actualizado exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.distritoRepository.createQueryBuilder()
            .update(distrito_entity_1.Distrito)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Distrito no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.DistritoService = DistritoService;
exports.DistritoService = DistritoService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(distrito_entity_1.Distrito)),
    __param(1, (0, typeorm_1.InjectRepository)(provincia_entity_1.Provincia)),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        typeorm_2.Repository])
], DistritoService);
//# sourceMappingURL=distrito.service.js.map