"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EstadoProyectoService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const estado_proyecto_entity_1 = require("./estado-proyecto.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let EstadoProyectoService = class EstadoProyectoService {
    constructor(estadoProyectoRepository) {
        this.estadoProyectoRepository = estadoProyectoRepository;
    }
    async getDataAll() {
        const estadoProyecto = await this.estadoProyectoRepository.createQueryBuilder('estado_proyecto')
            .andWhere('estado_proyecto.deleted_at IS NULL')
            .getMany();
        if (!estadoProyecto.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return estadoProyecto.map(estadoProyecto => ({
                ...estadoProyecto,
                created_at: (0, date_fns_1.format)(estadoProyecto.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(estadoProyecto.updated_at, 'dd/MM/yyyy'),
            }));
        }
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const [data, total] = await this.estadoProyectoRepository.createQueryBuilder('estado_proyecto')
            .andWhere('estado_proyecto.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(estadoProyecto => ({
                ...estadoProyecto,
                created_at: (0, date_fns_1.format)(estadoProyecto.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(estadoProyecto.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = this.estadoProyectoRepository.createQueryBuilder('estado_proyecto')
            .andWhere('estado_proyecto.deleted_at IS NULL');
        if (params.nombre) {
            console.log('params:');
            console.log(params);
            query.andWhere('estado_proyecto.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        console.log('data:');
        console.log(data);
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(estadoProyecto => ({
                ...estadoProyecto,
                created_at: (0, date_fns_1.format)(estadoProyecto.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(estadoProyecto.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async createData(estadoProyecto) {
        const estadoProyectoFound = await this.estadoProyectoRepository.findOne({
            where: {
                nombre: estadoProyecto.nombre,
                deleted_at: null
            }
        });
        if (estadoProyectoFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Estado de proyecto ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            const newEstadoProyecto = this.estadoProyectoRepository.create(estadoProyecto);
            const savedEstadoProyecto = await this.estadoProyectoRepository.save(newEstadoProyecto);
            const formattedData = {
                ...savedEstadoProyecto,
                created_at: (0, date_fns_1.format)(savedEstadoProyecto.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedEstadoProyecto.updated_at, 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Estado de proyecto creado exitosamente',
            };
        }
    }
    async getDataById(id) {
        const estadoProyecto = await this.estadoProyectoRepository.createQueryBuilder('estado_proyecto')
            .andWhere('estado_proyecto.deleted_at IS NULL')
            .where('estado_proyecto.id = :id', { id })
            .getOne();
        if (!estadoProyecto) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...estadoProyecto,
                created_at: (0, date_fns_1.format)(estadoProyecto.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(estadoProyecto.updated_at, 'dd/MM/yyyy'),
            };
        }
    }
    async updateData(id, estadoProyecto) {
        const estadoProyectoFound = await this.estadoProyectoRepository.findOne({
            where: {
                id: id
            }
        });
        if (!estadoProyectoFound) {
            return new common_1.HttpException('Tipo de inmueble no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const { created_at } = estadoProyectoFound;
            const updateEstadoProyecto = Object.assign(estadoProyectoFound, estadoProyecto);
            updateEstadoProyecto.updated_at = new Date();
            updateEstadoProyecto.created_at = created_at;
            const data = await this.estadoProyectoRepository.save(updateEstadoProyecto);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(new Date(data.created_at), 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(new Date(data.updated_at), 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Estado de proyecto actualizado exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.estadoProyectoRepository.createQueryBuilder()
            .update(estado_proyecto_entity_1.EstadoProyecto)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Estado Proyecto no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.EstadoProyectoService = EstadoProyectoService;
exports.EstadoProyectoService = EstadoProyectoService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(estado_proyecto_entity_1.EstadoProyecto)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], EstadoProyectoService);
//# sourceMappingURL=estado-proyecto.service.js.map