"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FavoritosService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const favoritos_entity_1 = require("./favoritos.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let FavoritosService = class FavoritosService {
    constructor(favoritoRepository) {
        this.favoritoRepository = favoritoRepository;
    }
    async createData(favorito) {
        const favoritoFound = await this.favoritoRepository.findOne({
            where: {
                inmueble_id: favorito.inmueble_id,
                user_id: favorito.user_id
            }
        });
        if (favoritoFound) {
            return new common_1.HttpException('El inmueble ya existe como favorito', common_1.HttpStatus.CONFLICT);
        }
        else {
            const newFavorito = this.favoritoRepository.create(favorito);
            const savedFavorito = await this.favoritoRepository.save(newFavorito);
            const formattedData = {
                ...savedFavorito,
                created_at: (0, date_fns_1.format)(savedFavorito.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedFavorito.updated_at, 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'El inmueble ha sido guardado como favorito exitosamente',
            };
        }
    }
    async getData() {
        const data = await this.favoritoRepository.createQueryBuilder('favoritos')
            .leftJoinAndSelect('favoritos.inmueble', 'inmueble')
            .leftJoinAndSelect('favoritos.user', 'user')
            .where('favoritos.deleted_at IS NULL')
            .getMany();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return data.map(favoritos => ({
                ...favoritos,
                created_at: (0, date_fns_1.format)(favoritos.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(favoritos.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...favoritos.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(favoritos.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(favoritos.inmueble.updated_at), 'dd/MM/yyyy'),
                },
                user: {
                    ...favoritos.user,
                    created_at: (0, date_fns_1.format)(new Date(favoritos.user.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(favoritos.user.updated_at), 'dd/MM/yyyy'),
                }
            }));
        }
    }
    async getDataById(id) {
        const favoritos = await this.favoritoRepository.createQueryBuilder('favoritos')
            .leftJoinAndSelect('favoritos.inmueble', 'inmueble')
            .leftJoinAndSelect('favoritos.user', 'user')
            .where('favoritos.deleted_at IS NULL')
            .where('favoritos.id = :id', { id })
            .getOne();
        if (!favoritos) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...favoritos,
                created_at: (0, date_fns_1.format)(favoritos.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(favoritos.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...favoritos.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(favoritos.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(favoritos.inmueble.updated_at), 'dd/MM/yyyy'),
                },
                user: {
                    ...favoritos.user,
                    created_at: (0, date_fns_1.format)(new Date(favoritos.user.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(favoritos.user.updated_at), 'dd/MM/yyyy'),
                }
            };
        }
    }
    async updateData(id, favorito) {
        const favoritoFound = await this.favoritoRepository.findOne({
            where: {
                id: id
            }
        });
        if (!favoritoFound) {
            return new common_1.HttpException('Favorito no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const updateFavorito = Object.assign(favoritoFound, favorito);
            updateFavorito.updated_at = new Date();
            return this.favoritoRepository.save(updateFavorito);
        }
    }
    async deleteData(id) {
        const rs = await this.favoritoRepository.createQueryBuilder()
            .update(favoritos_entity_1.Favoritos)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Favoritos no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.FavoritosService = FavoritosService;
exports.FavoritosService = FavoritosService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(favoritos_entity_1.Favoritos)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], FavoritosService);
//# sourceMappingURL=favoritos.service.js.map