"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GaleriaService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const galeria_entity_1 = require("./galeria.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let GaleriaService = class GaleriaService {
    constructor(galeriaRepository) {
        this.galeriaRepository = galeriaRepository;
    }
    async getData() {
        const data = await this.galeriaRepository.createQueryBuilder('galeria')
            .leftJoinAndSelect('galeria.inmueble', 'inmueble')
            .where('galeria.deleted_at IS NULL')
            .getMany();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return data.map(galeria => ({
                ...galeria,
                created_at: (0, date_fns_1.format)(galeria.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(galeria.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...galeria.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(galeria.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(galeria.inmueble.updated_at), 'dd/MM/yyyy'),
                },
            }));
        }
    }
    async getDataByInmueble(id) {
        const galeria = await this.galeriaRepository.createQueryBuilder('galeria')
            .leftJoinAndSelect('galeria.inmueble', 'perfil')
            .where('galeria.deleted_at IS NULL')
            .where('galeria.inmueble_id = :id', { id })
            .getMany();
        if (!galeria) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = galeria.map(galeria => ({
                ...galeria,
                created_at: (0, date_fns_1.format)(galeria.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(galeria.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...galeria.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(galeria.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(galeria.inmueble.updated_at), 'dd/MM/yyyy'),
                },
            }));
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Registros encontrados con éxito'
            };
        }
    }
    async getDataById(id) {
        const galeria = await this.galeriaRepository.createQueryBuilder('galeria')
            .leftJoinAndSelect('galeria.inmueble', 'perfil')
            .where('galeria.deleted_at IS NULL')
            .where('galeria.id = :id', { id })
            .getOne();
        if (!galeria) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...galeria,
                created_at: (0, date_fns_1.format)(galeria.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(galeria.updated_at, 'dd/MM/yyyy'),
                perfil: {
                    ...galeria.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(galeria.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(galeria.inmueble.updated_at), 'dd/MM/yyyy'),
                },
            };
        }
    }
    async createData(galeria) {
        const galeriaFound = await this.galeriaRepository.findOne({
            where: {
                url_desktop: galeria.url_desktop
            }
        });
        if (galeriaFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Galeria ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            const newGaleria = this.galeriaRepository.create(galeria);
            const savedGaleria = await this.galeriaRepository.save(newGaleria);
            const formattedData = {
                ...savedGaleria,
                created_at: (0, date_fns_1.format)(savedGaleria.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedGaleria.updated_at, 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Estado de proyecto creado exitosamente',
            };
        }
    }
    async updateData(id, galeria) {
        const galeriaFound = await this.galeriaRepository.findOne({
            where: {
                id: id
            }
        });
        if (!galeriaFound) {
            return new common_1.HttpException('Usuario no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const updateGaleria = Object.assign(galeriaFound, galeria);
            updateGaleria.updated_at = new Date();
            return this.galeriaRepository.save(updateGaleria);
        }
    }
    async deleteData(id) {
        const rs = await this.galeriaRepository.createQueryBuilder()
            .update(galeria_entity_1.Galeria)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Usuario no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.GaleriaService = GaleriaService;
exports.GaleriaService = GaleriaService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(galeria_entity_1.Galeria)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], GaleriaService);
//# sourceMappingURL=galeria.service.js.map