"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InmuebleAreasSocialesService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const inmueble_areas_sociales_entity_1 = require("./inmueble-areas-sociales.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let InmuebleAreasSocialesService = class InmuebleAreasSocialesService {
    constructor(inmuebleAreasSocialesRepository) {
        this.inmuebleAreasSocialesRepository = inmuebleAreasSocialesRepository;
    }
    async createData(inmuebleAreasSociales) {
        const { areasSociales } = inmuebleAreasSociales;
        if (!areasSociales || areasSociales.length === 0) {
            return new common_1.HttpException('No se proporcionaron áreas sociales', common_1.HttpStatus.BAD_REQUEST);
        }
        const areasIds = areasSociales.map(area => area.areas_sociales_id);
        const inmuebleId = areasSociales[0].inmueble_id;
        const existingRecords = await this.inmuebleAreasSocialesRepository.find({
            where: {
                inmueble_id: inmuebleId,
                areas_sociales_id: (0, typeorm_2.In)(areasIds)
            }
        });
        if (existingRecords.length > 0) {
            return new common_1.HttpException('Algunas áreas sociales ya están registradas', common_1.HttpStatus.CONFLICT);
        }
        const newRecords = areasSociales.map(area => ({
            inmueble_id: area.inmueble_id,
            areas_sociales_id: area.areas_sociales_id
        }));
        const formattedData = this.inmuebleAreasSocialesRepository.save(newRecords);
        return {
            data: formattedData,
            id: inmuebleId,
            status: common_1.HttpStatus.OK,
            message: 'Areas sociales agregadas exitosamente',
        };
    }
    async getData() {
        const data = await this.inmuebleAreasSocialesRepository.createQueryBuilder('inmueble_areas_sociales')
            .leftJoinAndSelect('inmueble_areas_sociales.inmueble', 'inmueble')
            .leftJoinAndSelect('inmueble_areas_sociales.areasSociales', 'areasSociales')
            .where('inmueble_areas_sociales.deleted_at IS NULL')
            .getMany();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return data.map(inmuebleAreasSociales => ({
                ...inmuebleAreasSociales,
                created_at: (0, date_fns_1.format)(inmuebleAreasSociales.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(inmuebleAreasSociales.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...inmuebleAreasSociales.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleAreasSociales.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleAreasSociales.inmueble.updated_at), 'dd/MM/yyyy'),
                },
                areasSociales: {
                    ...inmuebleAreasSociales.areasSociales,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleAreasSociales.areasSociales.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleAreasSociales.areasSociales.updated_at), 'dd/MM/yyyy'),
                }
            }));
        }
    }
    async getDataById(id) {
        const inmuebleAreasSociales = await this.inmuebleAreasSocialesRepository.createQueryBuilder('favoritos')
            .leftJoinAndSelect('inmueble_areas_sociales.inmueble', 'inmueble')
            .leftJoinAndSelect('inmueble_areas_sociales.areasSociales', 'areasSociales')
            .where('inmueble_areas_sociales.deleted_at IS NULL')
            .where('inmueble_areas_sociales.id = :id', { id })
            .getOne();
        if (!inmuebleAreasSociales) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...inmuebleAreasSociales,
                created_at: (0, date_fns_1.format)(inmuebleAreasSociales.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(inmuebleAreasSociales.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...inmuebleAreasSociales.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleAreasSociales.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleAreasSociales.inmueble.updated_at), 'dd/MM/yyyy'),
                },
                user: {
                    ...inmuebleAreasSociales.areasSociales,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleAreasSociales.areasSociales.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleAreasSociales.areasSociales.updated_at), 'dd/MM/yyyy'),
                }
            };
        }
    }
    async updateData(id, inmuebleAreasSociales) {
        const inmuebleAreasSocialesFound = await this.inmuebleAreasSocialesRepository.findOne({
            where: {
                id: id
            }
        });
        if (!inmuebleAreasSocialesFound) {
            return new common_1.HttpException('Favorito no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const updateInmuebleAreasSociales = Object.assign(inmuebleAreasSocialesFound, inmuebleAreasSociales);
            updateInmuebleAreasSociales.updated_at = new Date();
            return this.inmuebleAreasSocialesRepository.save(updateInmuebleAreasSociales);
        }
    }
    async deleteData(id) {
        const rs = await this.inmuebleAreasSocialesRepository.createQueryBuilder()
            .update(inmueble_areas_sociales_entity_1.InmuebleAreasSociales)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Inmueble Areas Sociales no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.InmuebleAreasSocialesService = InmuebleAreasSocialesService;
exports.InmuebleAreasSocialesService = InmuebleAreasSocialesService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(inmueble_areas_sociales_entity_1.InmuebleAreasSociales)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], InmuebleAreasSocialesService);
//# sourceMappingURL=inmueble-areas-sociales.service.js.map