"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InmuebleEstadosService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const inmueble_estados_entity_1 = require("./inmueble-estados.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let InmuebleEstadosService = class InmuebleEstadosService {
    constructor(inmuebleEstadosRepository) {
        this.inmuebleEstadosRepository = inmuebleEstadosRepository;
    }
    async createData(inmuebleEstados) {
        const { estados } = inmuebleEstados;
        if (!estados || estados.length === 0) {
            return new common_1.HttpException('No se proporcionaron áreas sociales', common_1.HttpStatus.BAD_REQUEST);
        }
        const estadosIds = estados.map(estados => estados.estado_proyecto_id);
        const inmuebleId = estados[0].inmueble_id;
        const existingRecords = await this.inmuebleEstadosRepository.find({
            where: {
                inmueble_id: inmuebleId,
                estado_proyecto_id: (0, typeorm_2.In)(estadosIds)
            }
        });
        if (existingRecords.length > 0) {
            return new common_1.HttpException('Algunos estados de proyecto ya están registradas', common_1.HttpStatus.CONFLICT);
        }
        const newRecords = estados.map(estados => ({
            inmueble_id: estados.inmueble_id,
            estado_proyecto_id: estados.estado_proyecto_id
        }));
        const formattedData = this.inmuebleEstadosRepository.save(newRecords);
        return {
            data: formattedData,
            id: inmuebleId,
            status: common_1.HttpStatus.OK,
            message: 'Areas sociales agregadas exitosamente',
        };
    }
    async getData() {
        const data = await this.inmuebleEstadosRepository.createQueryBuilder('inmueble_estados')
            .leftJoinAndSelect('inmueble_estados.inmueble', 'inmueble')
            .leftJoinAndSelect('inmueble_estados.estadoProyecto', 'estadoProyecto')
            .where('inmueble_estados.deleted_at IS NULL')
            .getMany();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return data.map(inmuebleEstados => ({
                ...inmuebleEstados,
                created_at: (0, date_fns_1.format)(inmuebleEstados.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(inmuebleEstados.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...inmuebleEstados.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleEstados.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleEstados.inmueble.updated_at), 'dd/MM/yyyy'),
                },
                estadoProyecto: {
                    ...inmuebleEstados.estadoProyecto,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleEstados.estadoProyecto.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleEstados.estadoProyecto.updated_at), 'dd/MM/yyyy'),
                }
            }));
        }
    }
    async getDataById(id) {
        const inmuebleEstados = await this.inmuebleEstadosRepository.createQueryBuilder('inmueble_estados')
            .leftJoinAndSelect('inmueble_estados.inmueble', 'inmueble')
            .leftJoinAndSelect('inmueble_estados.estadoProyecto', 'estadoProyecto')
            .where('inmueble_estados.deleted_at IS NULL')
            .where('inmueble_estados.id = :id', { id })
            .getOne();
        if (!inmuebleEstados) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...inmuebleEstados,
                created_at: (0, date_fns_1.format)(inmuebleEstados.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(inmuebleEstados.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...inmuebleEstados.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleEstados.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleEstados.inmueble.updated_at), 'dd/MM/yyyy'),
                },
                user: {
                    ...inmuebleEstados.estadoProyecto,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleEstados.estadoProyecto.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleEstados.estadoProyecto.updated_at), 'dd/MM/yyyy'),
                }
            };
        }
    }
    async updateData(id, inmuebleEstados) {
        const inmuebleEstadosFound = await this.inmuebleEstadosRepository.findOne({
            where: {
                id: id
            }
        });
        if (!inmuebleEstadosFound) {
            return new common_1.HttpException('Favorito no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const updateInmuebleEstados = Object.assign(inmuebleEstadosFound, inmuebleEstados);
            updateInmuebleEstados.updated_at = new Date();
            return this.inmuebleEstadosRepository.save(updateInmuebleEstados);
        }
    }
    async deleteData(id) {
        const rs = await this.inmuebleEstadosRepository.createQueryBuilder()
            .update(inmueble_estados_entity_1.InmuebleEstados)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Inmueble Estados de proyecto no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.InmuebleEstadosService = InmuebleEstadosService;
exports.InmuebleEstadosService = InmuebleEstadosService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(inmueble_estados_entity_1.InmuebleEstados)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], InmuebleEstadosService);
//# sourceMappingURL=inmueble-estados.service.js.map