"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InmuebleVistasService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const inmueble_vistas_entity_1 = require("./inmueble-vistas.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let InmuebleVistasService = class InmuebleVistasService {
    constructor(inmuebleVistasRepository) {
        this.inmuebleVistasRepository = inmuebleVistasRepository;
    }
    async createData(inmuebleVistas) {
        const { vistas } = inmuebleVistas;
        if (!vistas || vistas.length === 0) {
            return new common_1.HttpException('No se proporcionaron áreas sociales', common_1.HttpStatus.BAD_REQUEST);
        }
        const vistasIds = vistas.map(vistas => vistas.vista_id);
        const inmuebleId = vistas[0].inmueble_id;
        const existingRecords = await this.inmuebleVistasRepository.find({
            where: {
                inmueble_id: inmuebleId,
                vista_id: (0, typeorm_2.In)(vistasIds)
            }
        });
        if (existingRecords.length > 0) {
            return new common_1.HttpException('Algunos estados de proyecto ya están registradas', common_1.HttpStatus.CONFLICT);
        }
        const newRecords = vistas.map(vistas => ({
            inmueble_id: vistas.inmueble_id,
            vista_id: vistas.vista_id
        }));
        const formattedData = this.inmuebleVistasRepository.save(newRecords);
        return {
            data: formattedData,
            id: inmuebleId,
            status: common_1.HttpStatus.OK,
            message: 'Vistas agregadas exitosamente',
        };
    }
    async getData() {
        const data = await this.inmuebleVistasRepository.createQueryBuilder('inmueble_vistas')
            .leftJoinAndSelect('inmueble_vistas.inmueble', 'inmueble')
            .leftJoinAndSelect('inmueble_vistas.vista', 'vista')
            .where('inmueble_vistas.deleted_at IS NULL')
            .getMany();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return data.map(inmuebleVistas => ({
                ...inmuebleVistas,
                created_at: (0, date_fns_1.format)(inmuebleVistas.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(inmuebleVistas.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...inmuebleVistas.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleVistas.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleVistas.inmueble.updated_at), 'dd/MM/yyyy'),
                },
                vista: {
                    ...inmuebleVistas.vista,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleVistas.vista.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleVistas.vista.updated_at), 'dd/MM/yyyy'),
                }
            }));
        }
    }
    async getDataById(id) {
        const inmuebleVistas = await this.inmuebleVistasRepository.createQueryBuilder('inmueble_vistas')
            .leftJoinAndSelect('inmueble_vistas.inmueble', 'inmueble')
            .leftJoinAndSelect('inmueble_vistas.vista', 'vista')
            .where('inmueble_vistas.deleted_at IS NULL')
            .where('inmueble_vistas.id = :id', { id })
            .getOne();
        if (!inmuebleVistas) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...inmuebleVistas,
                created_at: (0, date_fns_1.format)(inmuebleVistas.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(inmuebleVistas.updated_at, 'dd/MM/yyyy'),
                inmueble: {
                    ...inmuebleVistas.inmueble,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleVistas.inmueble.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleVistas.inmueble.updated_at), 'dd/MM/yyyy'),
                },
                vista: {
                    ...inmuebleVistas.vista,
                    created_at: (0, date_fns_1.format)(new Date(inmuebleVistas.vista.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(inmuebleVistas.vista.updated_at), 'dd/MM/yyyy'),
                }
            };
        }
    }
    async updateData(id, inmuebleVistas) {
        const inmuebleVistasFound = await this.inmuebleVistasRepository.findOne({
            where: {
                id: id
            }
        });
        if (!inmuebleVistasFound) {
            return new common_1.HttpException('Vista no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const updateInmuebleVistas = Object.assign(inmuebleVistasFound, inmuebleVistas);
            updateInmuebleVistas.updated_at = new Date();
            return this.inmuebleVistasRepository.save(updateInmuebleVistas);
        }
    }
    async deleteData(id) {
        const rs = await this.inmuebleVistasRepository.createQueryBuilder()
            .update(inmueble_vistas_entity_1.InmuebleVistas)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Inmueble vistas de proyecto no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.InmuebleVistasService = InmuebleVistasService;
exports.InmuebleVistasService = InmuebleVistasService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(inmueble_vistas_entity_1.InmuebleVistas)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], InmuebleVistasService);
//# sourceMappingURL=inmueble-vistas.service.js.map