"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InmuebleWebController = void 0;
const common_1 = require("@nestjs/common");
const create_inmueble_web_dto_1 = require("./dto/create-inmueble-web.dto");
const inmueble_web_service_1 = require("./inmueble-web.service");
const update_inmueble_web_dto_1 = require("./dto/update-inmueble-web.dto");
const search_inmueble_web_dto_1 = require("./dto/search-inmueble-web.dto");
const axios_1 = require("axios");
const common_2 = require("@nestjs/common");
const auth_guard_1 = require("../auth/auth.guard");
const NodeCache = require("node-cache");
let InmuebleWebController = class InmuebleWebController {
    constructor(inmuebleWebService) {
        this.inmuebleWebService = inmuebleWebService;
        this.cache = new NodeCache({ stdTTL: 86400 });
    }
    getInmuebleAll() {
        return this.inmuebleWebService.getDataAll();
    }
    async getInmuebleTipoCambio() {
        const currentDate = new Date();
        const offset = currentDate.getTimezoneOffset() * 60000;
        const localDate = new Date(currentDate.getTime() - offset).toISOString().split('T')[0];
        const cachedData = this.cache.get(localDate);
        if (cachedData) {
            console.log('Retornando datos desde cache');
            return cachedData;
        }
        const url = `https://free.e-api.net.pe/tipo-cambio/${localDate}.json`;
        console.log('Consultando API:', url);
        try {
            const response = await axios_1.default.get(url);
            this.cache.set(localDate, response.data);
            return response.data;
        }
        catch (error) {
            console.error('Error en la API:', error.response?.data || error.message);
            throw new common_1.HttpException(error.response?.data?.error || 'Error al obtener el tipo de cambio', error.response?.status || common_1.HttpStatus.INTERNAL_SERVER_ERROR);
        }
    }
    getInmuebleByUser(userid) {
        return this.inmuebleWebService.getDataByUser(userid);
    }
    async getInmueble(page, limit) {
        if (page <= 0 || limit <= 0) {
            throw new common_1.HttpException('Los valores de página y límite deben ser mayores que 0', common_1.HttpStatus.BAD_REQUEST);
        }
        try {
            const data = await this.inmuebleWebService.getData(page, limit);
            return {
                statusCode: common_1.HttpStatus.OK,
                message: 'Datos obtenidos correctamente',
                data,
            };
        }
        catch (error) {
            throw new common_1.HttpException(error.message || 'Error al obtener datos', error.status || common_1.HttpStatus.INTERNAL_SERVER_ERROR);
        }
    }
    getInmuebleById(id) {
        return this.inmuebleWebService.getDataById(id);
    }
    async searchInmuebles(page, limit, body) {
        try {
            const data = await this.inmuebleWebService.searchData(page, limit, body);
            return {
                statusCode: common_1.HttpStatus.OK,
                message: 'Datos obtenidos correctamente',
                data,
            };
        }
        catch (error) {
            console.error('Error al buscar inmuebles:', error);
            throw new common_1.HttpException(error.message || 'Ocurrió un error al procesar la solicitud', error.status || common_1.HttpStatus.INTERNAL_SERVER_ERROR);
        }
    }
    createInmueble(newInmueble) {
        return this.inmuebleWebService.createInmueble(newInmueble);
    }
    updateInmueble(id, inmueble) {
        return this.inmuebleWebService.updateData(id, inmueble);
    }
    deleteInmueble(id) {
        return this.inmuebleWebService.deleteData(id);
    }
};
exports.InmuebleWebController = InmuebleWebController;
__decorate([
    (0, common_1.Get)('inmuebleAll'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], InmuebleWebController.prototype, "getInmuebleAll", null);
__decorate([
    (0, common_1.Get)('getTipoCambio'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], InmuebleWebController.prototype, "getInmuebleTipoCambio", null);
__decorate([
    (0, common_1.Get)('inmuebleByUser/:userid'),
    __param(0, (0, common_1.Param)('userid', common_1.ParseIntPipe)),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Number]),
    __metadata("design:returntype", void 0)
], InmuebleWebController.prototype, "getInmuebleByUser", null);
__decorate([
    (0, common_1.Get)(':page/:limit'),
    __param(0, (0, common_1.Param)('page', common_1.ParseIntPipe)),
    __param(1, (0, common_1.Param)('limit', common_1.ParseIntPipe)),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Number, Number]),
    __metadata("design:returntype", Promise)
], InmuebleWebController.prototype, "getInmueble", null);
__decorate([
    (0, common_1.Get)(':id'),
    __param(0, (0, common_1.Param)('id', common_1.ParseIntPipe)),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Number]),
    __metadata("design:returntype", void 0)
], InmuebleWebController.prototype, "getInmuebleById", null);
__decorate([
    (0, common_1.Post)('searchInmueble/:page/:limit'),
    __param(0, (0, common_1.Param)('page', common_1.ParseIntPipe)),
    __param(1, (0, common_1.Param)('limit', common_1.ParseIntPipe)),
    __param(2, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Number, Number, search_inmueble_web_dto_1.SearchInmuebleWebDto]),
    __metadata("design:returntype", Promise)
], InmuebleWebController.prototype, "searchInmuebles", null);
__decorate([
    (0, common_2.UseGuards)(auth_guard_1.AuthGuard),
    (0, common_1.Post)(),
    __param(0, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [create_inmueble_web_dto_1.CreateInmuebleWebDto]),
    __metadata("design:returntype", void 0)
], InmuebleWebController.prototype, "createInmueble", null);
__decorate([
    (0, common_2.UseGuards)(auth_guard_1.AuthGuard),
    (0, common_1.Patch)(':id'),
    __param(0, (0, common_1.Param)('id', common_1.ParseIntPipe)),
    __param(1, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Number, update_inmueble_web_dto_1.UpdateInmuebleWebDto]),
    __metadata("design:returntype", void 0)
], InmuebleWebController.prototype, "updateInmueble", null);
__decorate([
    (0, common_2.UseGuards)(auth_guard_1.AuthGuard),
    (0, common_1.Put)(':id'),
    __param(0, (0, common_1.Param)('id', common_1.ParseIntPipe)),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Number]),
    __metadata("design:returntype", void 0)
], InmuebleWebController.prototype, "deleteInmueble", null);
exports.InmuebleWebController = InmuebleWebController = __decorate([
    (0, common_1.Controller)('inmueble-web'),
    __metadata("design:paramtypes", [inmueble_web_service_1.InmuebleWebService])
], InmuebleWebController);
//# sourceMappingURL=inmueble-web.controller.js.map