"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const class_validator_1 = require("class-validator");
const express_1 = require("express");
const core_1 = require("@nestjs/core");
const app_module_1 = require("./app.module");
require("dotenv/config");
async function bootstrap() {
    const app = await core_1.NestFactory.create(app_module_1.AppModule);
    (0, class_validator_1.useContainer)(app.select(app_module_1.AppModule), { fallbackOnErrors: true });
    app.useGlobalPipes(new common_1.ValidationPipe({
        transform: true,
        whitelist: true,
        forbidNonWhitelisted: true,
        exceptionFactory: (errors) => {
            const formattedErrors = errors.reduce((acc, err) => {
                console.log(err);
                acc[err.property] = Object.keys(err.constraints || {}).map(rule => getErrorMessage(rule));
                return acc;
            }, {});
            return new common_1.BadRequestException({
                statusCode: 400,
                message: 'Error de validación',
                errors: formattedErrors,
            });
        },
    }));
    app.use((0, express_1.json)({ limit: '50mb' }));
    app.use((0, express_1.urlencoded)({ limit: '50mb', extended: true }));
    await app.listen(process.env.PORT ?? 4000);
}
function getErrorMessage(rule) {
    const messages = {
        isNotEmpty: 'Campo obligatorio',
        isString: 'Debe ser un texto',
        isNumber: 'Debe ser un número',
        isEmail: 'Formato de correo incorrecto',
        isInt: 'Debe ser un número entero',
        minLength: 'Longitud mínima no alcanzada',
        maxLength: 'Longitud máxima excedida',
        isBoolean: 'Debe ser verdadero o falso',
        IsEmailUniqueConstraint: 'El correo ya existe',
        matches: 'Solo debe contener números',
        containsSpecialCharacter: 'Al menos un carácter especial',
        containsLetter: 'Al menos una letra',
        containsNumber: 'Al menos un número',
        isMinLength: 'Al menos 8 caracteres',
        MatchPasswords: 'La confirmación de la contraseña no coincide con la contraseña'
    };
    return messages[rule] || 'Error de validación';
}
bootstrap();
//# sourceMappingURL=main.js.map