"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProvinciaService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const provincia_entity_1 = require("./provincia.entity");
const departamento_entity_1 = require("../departamento/departamento.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let ProvinciaService = class ProvinciaService {
    constructor(provinciaRepository, departamentoRepository) {
        this.provinciaRepository = provinciaRepository;
        this.departamentoRepository = departamentoRepository;
    }
    async getDataAll() {
        const provincia = await this.provinciaRepository.createQueryBuilder('provincia')
            .leftJoinAndSelect('provincia.distrito', 'distrito')
            .andWhere('distrito.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL')
            .getMany();
        if (!provincia.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return provincia.map(provincia => ({
                ...provincia,
                created_at: (0, date_fns_1.format)(provincia.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(provincia.updated_at, 'dd/MM/yyyy'),
                distrito: provincia.distrito.map(us => ({
                    ...us,
                    created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                })),
            }));
        }
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const [data, total] = await this.provinciaRepository.createQueryBuilder('provincia')
            .leftJoinAndSelect('provincia.distrito', 'distrito')
            .leftJoinAndSelect('provincia.departamento', 'departamento')
            .andWhere('distrito.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL')
            .andWhere('departamento.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(provincia => ({
                ...provincia,
                created_at: (0, date_fns_1.format)(provincia.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(provincia.updated_at, 'dd/MM/yyyy'),
                distrito: provincia.distrito.map(us => ({
                    ...us,
                    created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                })),
                departamento: {
                    ...provincia.departamento,
                    created_at: (0, date_fns_1.format)(new Date(provincia.departamento.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(provincia.departamento.updated_at), 'dd/MM/yyyy'),
                },
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = await this.provinciaRepository.createQueryBuilder('provincia')
            .leftJoinAndSelect('provincia.distrito', 'distrito')
            .leftJoinAndSelect('provincia.departamento', 'departamento')
            .andWhere('distrito.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL')
            .andWhere('departamento.deleted_at IS NULL');
        if (params.nombre) {
            query.andWhere('provincia.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        if (params.departamento_id) {
            query.andWhere('provincia.departamento_id = :departamento_id', { departamento_id: `${params.departamento_id}` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        console.log('data:');
        console.log(data);
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(provincia => ({
                ...provincia,
                created_at: (0, date_fns_1.format)(provincia.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(provincia.updated_at, 'dd/MM/yyyy'),
                distrito: provincia.distrito.map(us => ({
                    ...us,
                    created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                })),
                departamento: {
                    ...provincia.departamento,
                    created_at: (0, date_fns_1.format)(new Date(provincia.departamento.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(provincia.departamento.updated_at), 'dd/MM/yyyy'),
                },
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async getDataById(id) {
        const provincia = await this.provinciaRepository.createQueryBuilder('provincia')
            .leftJoinAndSelect('provincia.distrito', 'distrito')
            .andWhere('distrito.deleted_at IS NULL')
            .andWhere('provincia.deleted_at IS NULL')
            .where('provincia.id = :id', { id })
            .getOne();
        if (!provincia) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...provincia,
                created_at: (0, date_fns_1.format)(provincia.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(provincia.updated_at, 'dd/MM/yyyy'),
                distrito: provincia.distrito.map(us => ({
                    ...us,
                    created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                })),
            };
        }
    }
    async getDataByDepartamentoId(departamento_id) {
        const provincia = await this.provinciaRepository.createQueryBuilder('provincia')
            .andWhere('provincia.deleted_at IS NULL')
            .where('provincia.departamento_id = :departamento_id', { departamento_id })
            .getMany();
        if (!provincia.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return provincia.map(provincia => ({
                ...provincia,
                created_at: (0, date_fns_1.format)(provincia.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(provincia.updated_at, 'dd/MM/yyyy'),
            }));
        }
    }
    async createData(provincia) {
        const provinciaFound = await this.provinciaRepository.findOne({
            where: {
                nombre: provincia.nombre,
                deleted_at: null
            },
            relations: ['pais']
        });
        if (provinciaFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Provincia ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            let departamento = null;
            if (provincia.departamento_id) {
                departamento = await this.departamentoRepository.findOne({
                    where: { id: provincia.departamento_id },
                });
                if (!departamento) {
                    return new common_1.HttpException('Departamento no encontrado', common_1.HttpStatus.NOT_FOUND);
                }
            }
            const newProvincia = this.provinciaRepository.create({
                ...provincia,
                departamento,
            });
            const savedProvincia = await this.provinciaRepository.save(newProvincia);
            const formattedData = {
                ...savedProvincia,
                created_at: (0, date_fns_1.format)(savedProvincia.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedProvincia.updated_at, 'dd/MM/yyyy'),
                distrito: savedProvincia.distrito
                    ? savedProvincia.distrito.map((us) => ({
                        ...us,
                        created_at: (0, date_fns_1.format)(new Date(us.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(us.updated_at), 'dd/MM/yyyy'),
                    }))
                    : [],
                departamento: savedProvincia.departamento
                    ? {
                        ...savedProvincia.departamento,
                        created_at: (0, date_fns_1.format)(new Date(savedProvincia.departamento.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(savedProvincia.departamento.updated_at), 'dd/MM/yyyy'),
                    }
                    : null,
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Provincia creado exitosamente',
            };
        }
    }
    async updateData(id, provincia) {
        const provinciaFound = await this.provinciaRepository.findOne({
            where: {
                id: id
            }
        });
        if (!provinciaFound) {
            return new common_1.HttpException('provincia no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const { created_at } = provinciaFound;
            const updateProvincia = Object.assign(provinciaFound, provincia);
            updateProvincia.updated_at = new Date();
            updateProvincia.created_at = created_at;
            const data = await this.provinciaRepository.save(updateProvincia);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(new Date(data.created_at), 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(new Date(data.updated_at), 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Departamento actualizado exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.provinciaRepository.createQueryBuilder()
            .update(provincia_entity_1.Provincia)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Provincia no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.ProvinciaService = ProvinciaService;
exports.ProvinciaService = ProvinciaService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(provincia_entity_1.Provincia)),
    __param(1, (0, typeorm_1.InjectRepository)(departamento_entity_1.Departamento)),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        typeorm_2.Repository])
], ProvinciaService);
//# sourceMappingURL=provincia.service.js.map