"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TipoMonedaService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const tipo_moneda_entity_1 = require("./tipo-moneda.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let TipoMonedaService = class TipoMonedaService {
    constructor(tipoMonedaRepository) {
        this.tipoMonedaRepository = tipoMonedaRepository;
    }
    async getDataAll() {
        const tipoMoneda = await this.tipoMonedaRepository.createQueryBuilder('tipo_moneda')
            .where('tipo_moneda.deleted_at IS NULL')
            .getMany();
        if (!tipoMoneda.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return tipoMoneda.map(tipoMoneda => ({
                ...tipoMoneda,
                created_at: (0, date_fns_1.format)(tipoMoneda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoMoneda.updated_at, 'dd/MM/yyyy'),
            }));
        }
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const [data, total] = await this.tipoMonedaRepository.createQueryBuilder('tipo_moneda')
            .andWhere('tipo_moneda.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(tipoMoneda => ({
                ...tipoMoneda,
                created_at: (0, date_fns_1.format)(tipoMoneda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoMoneda.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = this.tipoMonedaRepository.createQueryBuilder('tipo_moneda')
            .andWhere('tipo_moneda.deleted_at IS NULL');
        if (params.nombre) {
            console.log('params:');
            console.log(params);
            query.andWhere('tipo_moneda.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        console.log('data:');
        console.log(data);
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(tipoMoneda => ({
                ...tipoMoneda,
                created_at: (0, date_fns_1.format)(tipoMoneda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoMoneda.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async getDataById(id) {
        const tipoMoneda = await this.tipoMonedaRepository.createQueryBuilder('tipo_moneda')
            .andWhere('tipo_moneda.deleted_at IS NULL')
            .where('tipo_moneda.id = :id', { id })
            .getOne();
        if (!tipoMoneda) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...tipoMoneda,
                created_at: (0, date_fns_1.format)(tipoMoneda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoMoneda.updated_at, 'dd/MM/yyyy'),
            };
        }
    }
    async createData(tipoMoneda) {
        const tipoMonedaFound = await this.tipoMonedaRepository.findOne({
            where: {
                nombre: tipoMoneda.nombre,
                deleted_at: null
            }
        });
        if (tipoMonedaFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Tipo de Moneda ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            const newTipoMoneda = this.tipoMonedaRepository.create(tipoMoneda);
            const savedTipoMoneda = await this.tipoMonedaRepository.save(newTipoMoneda);
            const formattedData = {
                ...savedTipoMoneda,
                created_at: (0, date_fns_1.format)(savedTipoMoneda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedTipoMoneda.updated_at, 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Tipo de Moneda creada exitosamente',
            };
        }
    }
    async updateData(id, tipoMoneda) {
        const tipoMonedaFound = await this.tipoMonedaRepository.findOne({
            where: {
                id: id
            }
        });
        if (!tipoMonedaFound) {
            return new common_1.HttpException('Tipo de Moneda no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const { created_at } = tipoMonedaFound;
            const updateTipoMoneda = Object.assign(tipoMonedaFound, tipoMoneda);
            updateTipoMoneda.updated_at = new Date();
            updateTipoMoneda.created_at = created_at;
            const data = await this.tipoMonedaRepository.save(updateTipoMoneda);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(new Date(data.created_at), 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(new Date(data.updated_at), 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Tipo de Moneda actualizado exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.tipoMonedaRepository.createQueryBuilder()
            .update(tipo_moneda_entity_1.TipoMoneda)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Tipo Moneda no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.TipoMonedaService = TipoMonedaService;
exports.TipoMonedaService = TipoMonedaService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(tipo_moneda_entity_1.TipoMoneda)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], TipoMonedaService);
//# sourceMappingURL=tipo-moneda.service.js.map