"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TipoOperacionService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const tipo_operacion_entity_1 = require("./tipo-operacion.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
const users_service_1 = require("../users/users.service");
let TipoOperacionService = class TipoOperacionService {
    constructor(tipoOperacionRepository, _userService) {
        this.tipoOperacionRepository = tipoOperacionRepository;
        this._userService = _userService;
    }
    async getDataAll() {
        const tipoOperacion = await this.tipoOperacionRepository.createQueryBuilder('tipo_operacion')
            .where('tipo_operacion.deleted_at IS NULL')
            .getMany();
        if (!tipoOperacion.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return tipoOperacion.map(tipoOperacion => ({
                ...tipoOperacion,
                created_at: (0, date_fns_1.format)(tipoOperacion.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoOperacion.updated_at, 'dd/MM/yyyy'),
            }));
        }
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const [data, total] = await this.tipoOperacionRepository.createQueryBuilder('tipo_operacion')
            .andWhere('tipo_operacion.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(tipoOperacion => ({
                ...tipoOperacion,
                created_at: (0, date_fns_1.format)(tipoOperacion.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoOperacion.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = this.tipoOperacionRepository.createQueryBuilder('tipo_operacion')
            .andWhere('tipo_operacion.deleted_at IS NULL');
        if (params.nombre) {
            console.log('params:');
            console.log(params);
            query.andWhere('tipo_operacion.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        console.log('data:');
        console.log(data);
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(tipoOperacion => ({
                ...tipoOperacion,
                created_at: (0, date_fns_1.format)(tipoOperacion.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoOperacion.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async getDataById(id) {
        const tipoOperacion = await this.tipoOperacionRepository.createQueryBuilder('tipo_operacion')
            .andWhere('tipo_operacion.deleted_at IS NULL')
            .where('tipo_operacion.id = :id', { id })
            .getOne();
        if (!tipoOperacion) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...tipoOperacion,
                created_at: (0, date_fns_1.format)(tipoOperacion.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoOperacion.updated_at, 'dd/MM/yyyy'),
            };
        }
    }
    async createData(tipoOperacion) {
        const tipoOperacionFound = await this.tipoOperacionRepository.findOne({
            where: {
                nombre: tipoOperacion.nombre,
                deleted_at: null
            }
        });
        if (tipoOperacionFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Tipo de operación ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            const newTipoOperacion = this.tipoOperacionRepository.create(tipoOperacion);
            const savedTipoOperacion = await this.tipoOperacionRepository.save(newTipoOperacion);
            const formattedData = {
                ...savedTipoOperacion,
                created_at: (0, date_fns_1.format)(savedTipoOperacion.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedTipoOperacion.updated_at, 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Tipo de operación creada exitosamente',
            };
        }
    }
    async updateData(id, tipoOperacion) {
        const tipoOperacionFound = await this.tipoOperacionRepository.findOne({
            where: {
                id: id
            }
        });
        if (!tipoOperacionFound) {
            return new common_1.HttpException('Tipo de operación no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const { created_at } = tipoOperacionFound;
            const updateTipoOperacion = Object.assign(tipoOperacionFound, tipoOperacion);
            updateTipoOperacion.updated_at = new Date();
            updateTipoOperacion.created_at = created_at;
            const data = await this.tipoOperacionRepository.save(updateTipoOperacion);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(new Date(data.created_at), 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(new Date(data.updated_at), 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Tipo de operación actualizado exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.tipoOperacionRepository.createQueryBuilder()
            .update(tipo_operacion_entity_1.TipoOperacion)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Tipo operación no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.TipoOperacionService = TipoOperacionService;
exports.TipoOperacionService = TipoOperacionService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(tipo_operacion_entity_1.TipoOperacion)),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        users_service_1.UsersService])
], TipoOperacionService);
//# sourceMappingURL=tipo-operacion.service.js.map