"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TipoViviendaService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const tipo_vivienda_entity_1 = require("./tipo-vivienda.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let TipoViviendaService = class TipoViviendaService {
    constructor(tipoViviendaRepository) {
        this.tipoViviendaRepository = tipoViviendaRepository;
    }
    async getDataAll() {
        const tipoVivienda = await this.tipoViviendaRepository.createQueryBuilder('tipo_vivienda')
            .where('tipo_vivienda.deleted_at IS NULL')
            .getMany();
        if (!tipoVivienda.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return tipoVivienda.map(tipoVivienda => ({
                ...tipoVivienda,
                created_at: (0, date_fns_1.format)(tipoVivienda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoVivienda.updated_at, 'dd/MM/yyyy'),
            }));
        }
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const [data, total] = await this.tipoViviendaRepository.createQueryBuilder('tipo_vivienda')
            .andWhere('tipo_vivienda.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(tipoVivienda => ({
                ...tipoVivienda,
                created_at: (0, date_fns_1.format)(tipoVivienda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoVivienda.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = this.tipoViviendaRepository.createQueryBuilder('tipo_vivienda')
            .andWhere('tipo_vivienda.deleted_at IS NULL');
        if (params.nombre) {
            console.log('params:');
            console.log(params);
            query.andWhere('tipo_vivienda.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        console.log('data:');
        console.log(data);
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(tipoVivienda => ({
                ...tipoVivienda,
                created_at: (0, date_fns_1.format)(tipoVivienda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoVivienda.updated_at, 'dd/MM/yyyy'),
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async getDataById(id) {
        const tipoVivienda = await this.tipoViviendaRepository.createQueryBuilder('tipo_vivienda')
            .andWhere('tipo_vivienda.deleted_at IS NULL')
            .where('tipo_vivienda.id = :id', { id })
            .getOne();
        if (!tipoVivienda) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...tipoVivienda,
                created_at: (0, date_fns_1.format)(tipoVivienda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(tipoVivienda.updated_at, 'dd/MM/yyyy'),
            };
        }
    }
    async createTipoVivienda(tipoVivienda) {
        const tipoViviendaFound = await this.tipoViviendaRepository.findOne({
            where: {
                nombre: tipoVivienda.nombre,
                deleted_at: null
            }
        });
        if (tipoViviendaFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Tipo de vivienda ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            const newTipoVivienda = this.tipoViviendaRepository.create(tipoVivienda);
            const savedTipoVivienda = await this.tipoViviendaRepository.save(newTipoVivienda);
            const formattedData = {
                ...savedTipoVivienda,
                created_at: (0, date_fns_1.format)(savedTipoVivienda.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(savedTipoVivienda.updated_at, 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Tipo de vivienda creada exitosamente',
            };
        }
    }
    async updateData(id, tipoVivienda) {
        const tipoViviendaFound = await this.tipoViviendaRepository.findOne({
            where: {
                id: id
            }
        });
        if (!tipoViviendaFound) {
            return new common_1.HttpException('Tipo de vivienda no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const { created_at } = tipoViviendaFound;
            const updateTipoVivienda = Object.assign(tipoViviendaFound, tipoVivienda);
            updateTipoVivienda.updated_at = new Date();
            updateTipoVivienda.created_at = created_at;
            const data = await this.tipoViviendaRepository.save(updateTipoVivienda);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(new Date(data.created_at), 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(new Date(data.updated_at), 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Tipo de vivienda actualizado exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.tipoViviendaRepository.createQueryBuilder()
            .update(tipo_vivienda_entity_1.TipoVivienda)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Tipo Vivienda no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.TipoViviendaService = TipoViviendaService;
exports.TipoViviendaService = TipoViviendaService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(tipo_vivienda_entity_1.TipoVivienda)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], TipoViviendaService);
//# sourceMappingURL=tipo-vivienda.service.js.map