"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UsersService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const user_entity_1 = require("./user.entity");
const perfil_entity_1 = require("../perfil/perfil.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
const bcrypt = require("bcrypt");
const class_transformer_1 = require("class-transformer");
const jwt_1 = require("@nestjs/jwt");
let UsersService = class UsersService {
    constructor(userRepository, perfilRepository, horasValidas, jwtService) {
        this.userRepository = userRepository;
        this.perfilRepository = perfilRepository;
        this.horasValidas = horasValidas;
        this.jwtService = jwtService;
    }
    async isEmailUnique(correo, userId) {
        console.log('correo:' + correo);
        const user = await this.userRepository.findOne({ where: { correo } });
        console.log('result: ');
        console.log(user);
        if (user) {
            return true;
        }
        else {
            return false;
        }
    }
    async isEmailUniqueUpd(correo, userId) {
        console.log('correo:' + correo);
        const user = await this.userRepository.findOne({ where: { correo } });
        console.log('result: ');
        console.log(user);
        if (user.id == userId) {
            return true;
        }
        else {
            return false;
        }
    }
    async findByEmail(email) {
        const userFound = await this.userRepository.findOne({ where: { correo: email } });
        return (0, class_transformer_1.classToPlain)(userFound);
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 2;
        const offset = (page - 1) * limit;
        const [data, total] = await this.userRepository.createQueryBuilder('user')
            .leftJoinAndSelect('user.perfil', 'perfil')
            .where('user.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(user => ({
                id: user.id,
                nombre: user.nombre,
                apellido: user.apellido,
                imagen: user.imagen,
                telefono: user.telefono,
                correo: user.correo,
                created_at: (0, date_fns_1.format)(user.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(user.updated_at, 'dd/MM/yyyy'),
                perfil: user.perfil
                    ? {
                        id: user.perfil.id,
                        nombre: user.perfil.nombre,
                        created_at: (0, date_fns_1.format)(new Date(user.perfil.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(user.perfil.updated_at), 'dd/MM/yyyy'),
                    }
                    : null,
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = this.userRepository.createQueryBuilder('user')
            .leftJoinAndSelect('user.perfil', 'perfil')
            .where('user.deleted_at IS NULL');
        if (params.perfil_id) {
            query.andWhere('user.perfil_id = :perfil_id', { perfil_id: params.perfil_id });
        }
        if (params.nombre) {
            query.andWhere('user.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        if (params.apellido) {
            query.andWhere('user.apellido LIKE :apellido', { apellido: `%${params.apellido}%` });
        }
        if (params.correo) {
            query.andWhere('user.correo LIKE :correo', { correo: `%${params.correo}%` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(user => ({
                id: user.id,
                nombre: user.nombre,
                apellido: user.apellido,
                imagen: user.imagen,
                telefono: user.telefono,
                correo: user.correo,
                created_at: (0, date_fns_1.format)(user.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(user.updated_at, 'dd/MM/yyyy'),
                perfil: user.perfil
                    ? {
                        id: user.perfil.id,
                        nombre: user.perfil.nombre,
                        created_at: (0, date_fns_1.format)(new Date(user.perfil.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(user.perfil.updated_at), 'dd/MM/yyyy'),
                    }
                    : null,
            }));
            return {
                data: (0, class_transformer_1.classToPlain)(formattedData),
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async getDataById(id) {
        const user = await this.userRepository.createQueryBuilder('user')
            .leftJoinAndSelect('user.perfil', 'perfil')
            .leftJoinAndSelect('user.favoritos', 'favoritos', 'favoritos.deleted_at IS NULL')
            .leftJoinAndSelect('favoritos.inmueble', 'inmueble', 'inmueble.deleted_at IS NULL')
            .where('user.deleted_at IS NULL')
            .andWhere('user.id = :id', { id })
            .getOne();
        if (!user) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                id: user.id,
                nombre: user.nombre,
                apellido: user.apellido,
                imagen: user.imagen,
                telefono: user.telefono,
                correo: user.correo,
                perfil_id: user.perfil_id,
                created_at: (0, date_fns_1.format)(user.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(user.updated_at, 'dd/MM/yyyy'),
                perfil: user.perfil
                    ? {
                        id: user.perfil.id,
                        nombre: user.perfil.nombre,
                        created_at: (0, date_fns_1.format)(new Date(user.perfil.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(user.perfil.updated_at), 'dd/MM/yyyy'),
                    }
                    : null,
                favoritos: user.favoritos.map(fav => ({
                    ...fav,
                    created_at: (0, date_fns_1.format)(new Date(fav.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(fav.updated_at), 'dd/MM/yyyy'),
                    inmueble: {
                        ...fav.inmueble,
                        created_at: (0, date_fns_1.format)(new Date(fav.inmueble.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(fav.inmueble.updated_at), 'dd/MM/yyyy'),
                    }
                }))
            };
        }
    }
    async createUser(user) {
        const userFound = await this.userRepository.findOne({
            where: { correo: user.correo, deleted_at: null },
            relations: ['perfil'],
        });
        if (userFound) {
            throw new common_1.HttpException('Usuario ya existe', common_1.HttpStatus.CONFLICT);
        }
        let perfil = null;
        if (user.perfil_id) {
            perfil = await this.perfilRepository.findOne({ where: { id: user.perfil_id } });
            if (!perfil) {
                throw new common_1.HttpException('Perfil no encontrado', common_1.HttpStatus.NOT_FOUND);
            }
        }
        const hashedPassword = await bcrypt.hash(user.password, 10);
        const newUser = this.userRepository.create({
            ...user,
            password: hashedPassword,
            updated_at_token: new Date(),
            perfil,
        });
        const savedUser = await this.userRepository.save(newUser);
        const payload = { id: savedUser.id, correo: savedUser.correo };
        savedUser.token = await this.jwtService.signAsync(payload);
        await this.userRepository.save(savedUser);
        const formatDate = (date) => (date ? (0, date_fns_1.format)(date, 'dd/MM/yyyy') : null);
        return {
            data: {
                ...savedUser,
                created_at: formatDate(savedUser.created_at),
                updated_at: formatDate(savedUser.updated_at),
                perfil: perfil
                    ? {
                        ...perfil,
                        created_at: formatDate(perfil.created_at),
                        updated_at: formatDate(perfil.updated_at),
                    }
                    : null,
            },
            status: common_1.HttpStatus.OK,
            message: 'Usuario creado exitosamente',
        };
    }
    async updateData(id, user) {
        const userFound = await this.userRepository.findOne({
            where: {
                id: id
            },
            relations: ['perfil'],
        });
        if (!userFound) {
            return new common_1.HttpException('Usuario no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            if (user.perfil_id) {
                const perfil = await this.perfilRepository.findOne({
                    where: { id: user.perfil_id },
                });
                if (!perfil) {
                    throw new common_1.HttpException('Perfil no encontrado', common_1.HttpStatus.NOT_FOUND);
                }
                userFound.perfil = perfil;
            }
            if (user.password) {
                const saltRounds = 10;
                user.password = await bcrypt.hash(user.password, saltRounds);
            }
            const updateUser = Object.assign(userFound, user);
            updateUser.updated_at = new Date();
            const data = await this.userRepository.save(updateUser);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(data.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(data.updated_at, 'dd/MM/yyyy'),
                perfil: {
                    ...data.perfil,
                    created_at: (0, date_fns_1.format)(new Date(data.perfil.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(data.perfil.updated_at), 'dd/MM/yyyy'),
                },
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Usuario actualizado exitosamente',
            };
        }
    }
    async updatePass(id, user) {
        const userFound = await this.userRepository.findOne({
            where: {
                id: id
            }
        });
        if (!userFound) {
            return new common_1.HttpException('Tipo de ubicación no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const { created_at } = userFound;
            if (user.password) {
                const saltRounds = 10;
                user.password = await bcrypt.hash(user.password, saltRounds);
            }
            const updateUser = Object.assign(userFound, user);
            updateUser.updated_at = new Date();
            updateUser.created_at = created_at ? created_at : new Date();
            const data = await this.userRepository.save(updateUser);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(new Date(data.created_at), 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(new Date(data.updated_at), 'dd/MM/yyyy')
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Contraseña actualizada exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.userRepository.createQueryBuilder()
            .update(user_entity_1.User)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Usuario no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
    async loginUser(inputCorreo, inputPassword) {
        const userFound = await this.userRepository.findOne({
            where: {
                correo: inputCorreo
            },
        });
        if (!userFound) {
            return new common_1.HttpException('Usuario no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const isPasswordValid = await bcrypt.compare(inputPassword, userFound.password);
            if (!isPasswordValid) {
                return new common_1.HttpException('Contraseña incorrecta', common_1.HttpStatus.NOT_FOUND);
            }
            else {
                const payload = { id: userFound.id, correo: userFound.correo };
                const token = this.jwtService.sign(payload);
                userFound.updated_at_token = new Date();
                userFound.token = token;
                const data = await this.userRepository.save(userFound);
                return {
                    userFound: (0, class_transformer_1.classToPlain)(userFound),
                    status: common_1.HttpStatus.OK,
                    message: 'Bienvenido ' + userFound.nombre + ' ' + userFound.apellido,
                };
            }
        }
    }
    async validaUserActive(id, token) {
        const userFound = await this.userRepository.findOne({
            where: { id, token },
            select: ['correo', 'nombre', 'apellido', 'token', 'updated_at_token']
        });
        console.log('userfound: ' + userFound);
        if (!userFound) {
            return new common_1.HttpException('Usuario no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const fechaActualMs = Date.now();
            const fechaTokenMs = new Date(userFound.updated_at_token).getTime();
            const horasTranscurridas = (fechaActualMs - fechaTokenMs) / 3600000;
            if (horasTranscurridas > this.horasValidas) {
                return new common_1.HttpException('Tiempo terminado', common_1.HttpStatus.GATEWAY_TIMEOUT);
            }
            else {
                return {
                    userFound: userFound,
                    status: common_1.HttpStatus.OK,
                    horasTranscurridas: horasTranscurridas,
                    horasValidas: this.horasValidas,
                    message: 'Puede continuar con la session',
                };
            }
        }
    }
};
exports.UsersService = UsersService;
exports.UsersService = UsersService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(user_entity_1.User)),
    __param(1, (0, typeorm_1.InjectRepository)(perfil_entity_1.Perfil)),
    __param(2, (0, common_1.Inject)('SOME_NUMBER')),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        typeorm_2.Repository, Number, jwt_1.JwtService])
], UsersService);
//# sourceMappingURL=users.service.js.map