"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.VistaService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const vista_entity_1 = require("./vista.entity");
const tipo_vista_entity_1 = require("../tipo-vista/tipo-vista.entity");
const typeorm_2 = require("typeorm");
const date_fns_1 = require("date-fns");
let VistaService = class VistaService {
    constructor(vistaRepository, tipoVistaRepository) {
        this.vistaRepository = vistaRepository;
        this.tipoVistaRepository = tipoVistaRepository;
    }
    async getDataAll() {
        const data = await this.vistaRepository.createQueryBuilder('vista')
            .innerJoinAndSelect('vista.tipoVista', 'tipoVista', 'tipoVista.deleted_at IS NULL')
            .where('vista.deleted_at IS NULL')
            .getMany();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return data.map(vista => ({
                ...vista,
                created_at: (0, date_fns_1.format)(vista.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(vista.updated_at, 'dd/MM/yyyy'),
                tipoVista: vista.tipoVista ? {
                    ...vista.tipoVista,
                    created_at: (0, date_fns_1.format)(new Date(vista.tipoVista.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(vista.tipoVista.updated_at), 'dd/MM/yyyy'),
                } : null,
            }));
        }
    }
    async getData(page = 1, limit = 2) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const [data, total] = await this.vistaRepository.createQueryBuilder('vista')
            .innerJoinAndSelect('vista.tipoVista', 'tipoVista', 'tipoVista.deleted_at IS NULL')
            .where('vista.deleted_at IS NULL')
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(vista => ({
                ...vista,
                created_at: (0, date_fns_1.format)(vista.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(vista.updated_at, 'dd/MM/yyyy'),
                tipoVista: vista.tipoVista ? {
                    ...vista.tipoVista,
                    created_at: (0, date_fns_1.format)(new Date(vista.tipoVista.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(vista.tipoVista.updated_at), 'dd/MM/yyyy'),
                } : null,
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async searchData(page = 1, limit = 9, params) {
        if (page < 1)
            page = 1;
        if (limit < 1)
            limit = 9;
        const offset = (page - 1) * limit;
        const query = this.vistaRepository.createQueryBuilder('vista')
            .innerJoinAndSelect('vista.tipoVista', 'tipoVista', 'tipoVista.deleted_at IS NULL')
            .where('vista.deleted_at IS NULL');
        if (params.nombre) {
            query.andWhere('vista.nombre LIKE :nombre', { nombre: `%${params.nombre}%` });
        }
        if (params.tipo_vista_id) {
            query.andWhere('tipoVista.id = :tipo_vista_id', { tipo_vista_id: `${params.tipo_vista_id}` });
        }
        const [data, total] = await query
            .skip(offset)
            .take(limit)
            .getManyAndCount();
        console.log('data:');
        console.log(data);
        if (!data.length) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            const formattedData = data.map(vista => ({
                ...vista,
                created_at: (0, date_fns_1.format)(vista.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(vista.updated_at, 'dd/MM/yyyy'),
                perfil: {
                    ...vista.tipoVista,
                    created_at: (0, date_fns_1.format)(new Date(vista.tipoVista.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(vista.tipoVista.updated_at), 'dd/MM/yyyy'),
                },
            }));
            return {
                data: formattedData,
                meta: {
                    total,
                    page,
                    limit,
                    totalPages: Math.ceil(total / limit),
                },
            };
        }
    }
    async getDataById(id) {
        const vista = await this.vistaRepository.createQueryBuilder('vista')
            .innerJoinAndSelect('vista.tipoVista', 'tipoVista', 'tipoVista.deleted_at IS NULL')
            .where('vista.deleted_at IS NULL')
            .andWhere('vista.id = :id', { id })
            .getOne();
        if (!vista) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return {
                ...vista,
                created_at: (0, date_fns_1.format)(vista.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(vista.updated_at, 'dd/MM/yyyy'),
                perfil: {
                    ...vista.tipoVista,
                    created_at: (0, date_fns_1.format)(new Date(vista.tipoVista.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(vista.tipoVista.updated_at), 'dd/MM/yyyy'),
                },
            };
        }
    }
    async getDataByTipoVistaId(tipo_vista_id) {
        const vista = await this.vistaRepository.createQueryBuilder('vista')
            .innerJoinAndSelect('vista.tipoVista', 'tipoVista', 'tipoVista.deleted_at IS NULL')
            .where('vista.deleted_at IS NULL')
            .andWhere('vista.tipo_vista_id = :tipo_vista_id', { tipo_vista_id })
            .getMany();
        if (!vista) {
            return new common_1.HttpException('No existen registros', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return vista.map(vista => ({
                ...vista,
                created_at: (0, date_fns_1.format)(vista.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(vista.updated_at, 'dd/MM/yyyy'),
                tipoVista: vista.tipoVista ? {
                    ...vista.tipoVista,
                    created_at: (0, date_fns_1.format)(new Date(vista.tipoVista.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(vista.tipoVista.updated_at), 'dd/MM/yyyy'),
                } : null,
            }));
        }
    }
    async createVista(vista) {
        const vistaFound = await this.vistaRepository.findOne({
            where: {
                nombre: vista.nombre,
                deleted_at: null
            },
            relations: ['tipoVista']
        });
        if (vistaFound) {
            return new common_1.HttpException({
                status: common_1.HttpStatus.CONFLICT,
                message: 'Vista ya existe',
            }, common_1.HttpStatus.CONFLICT);
        }
        else {
            let tipoVista = null;
            if (vista.tipo_vista_id) {
                tipoVista = await this.tipoVistaRepository.findOne({
                    where: { id: vista.tipo_vista_id },
                });
                if (!tipoVista) {
                    return new common_1.HttpException('Tipo vista no encontrado', common_1.HttpStatus.NOT_FOUND);
                }
            }
            const newVista = this.vistaRepository.create({
                ...vista,
                tipoVista,
            });
            const data = await this.vistaRepository.save(newVista);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(data.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(data.updated_at, 'dd/MM/yyyy'),
                perfil: data.tipoVista
                    ? {
                        ...data.tipoVista,
                        created_at: (0, date_fns_1.format)(new Date(data.tipoVista.created_at), 'dd/MM/yyyy'),
                        updated_at: (0, date_fns_1.format)(new Date(data.tipoVista.updated_at), 'dd/MM/yyyy'),
                    }
                    : null,
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Perfil creado exitosamente',
            };
        }
    }
    async updateData(id, vista) {
        const vistaFound = await this.vistaRepository.findOne({
            where: {
                id: id
            },
            relations: ['tipoVista'],
        });
        if (!vistaFound) {
            return new common_1.HttpException('Vista no encontrada', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            if (vista.tipo_vista_id) {
                const tipoVista = await this.tipoVistaRepository.findOne({
                    where: { id: vista.tipo_vista_id },
                });
                if (!tipoVista) {
                    throw new common_1.HttpException('Tipo vista no encontrada', common_1.HttpStatus.NOT_FOUND);
                }
                vistaFound.tipoVista = tipoVista;
            }
            const { created_at } = vistaFound;
            const updateVista = Object.assign(vistaFound, vista);
            updateVista.updated_at = new Date();
            updateVista.created_at = created_at;
            const data = await this.vistaRepository.save(updateVista);
            const formattedData = {
                ...data,
                created_at: (0, date_fns_1.format)(data.created_at, 'dd/MM/yyyy'),
                updated_at: (0, date_fns_1.format)(data.updated_at, 'dd/MM/yyyy'),
                tipoVista: {
                    ...data.tipoVista,
                    created_at: (0, date_fns_1.format)(new Date(data.tipoVista.created_at), 'dd/MM/yyyy'),
                    updated_at: (0, date_fns_1.format)(new Date(data.tipoVista.updated_at), 'dd/MM/yyyy'),
                },
            };
            return {
                data: formattedData,
                status: common_1.HttpStatus.OK,
                message: 'Usuario actualizado exitosamente',
            };
        }
    }
    async deleteData(id) {
        const rs = await this.vistaRepository.createQueryBuilder()
            .update(vista_entity_1.Vista)
            .set({ deleted_at: () => 'CURRENT_TIMESTAMP' })
            .where('id = :id', { id })
            .execute();
        if (rs.affected === 0) {
            console.log(rs.affected);
            return new common_1.HttpException('Tipo vista no encontrado', common_1.HttpStatus.NOT_FOUND);
        }
        else {
            return rs;
        }
    }
};
exports.VistaService = VistaService;
exports.VistaService = VistaService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(vista_entity_1.Vista)),
    __param(1, (0, typeorm_1.InjectRepository)(tipo_vista_entity_1.TipoVista)),
    __metadata("design:paramtypes", [typeorm_2.Repository,
        typeorm_2.Repository])
], VistaService);
//# sourceMappingURL=vista.service.js.map